import { LocalStorageService } from './LocalStorageService'
import type { StorageInterface } from './StorageInterface'
import { TauriFileStorageService } from './TauriFileStorageService'

export class PersistenceService {
  private static instance: PersistenceService
  private isTauri: boolean = false
  private storage: StorageInterface
  private constructor() {
    this.isTauri = window.__TAURI_METADATA__ ? true : false
    this.storage = this.isTauri ? new TauriFileStorageService() : new LocalStorageService()
    console.log('PersistenceService created', this.isTauri)
  }

  static getInstance(): PersistenceService {
    if (!PersistenceService.instance) {
      PersistenceService.instance = new PersistenceService()
    }
    return PersistenceService.instance
  }

  async saveToken(token: string) {
    await this.storage.saveUserDataText('token', token)
  }

  async saveRefreshToken(refreshToken: string) {
    await this.storage.saveUserDataText('refreshToken', refreshToken)
  }

  async readToken(): Promise<string> {
    try {
      const token = await this.storage.readUserDataText('token')
      return token
    } catch (error) {
      console.error(error)
      return ''
    }
  }

  async readRefreshToken() {
    try {
      const refreshToken = await this.storage.readUserDataText('refreshToken')
      return refreshToken
    } catch (error) {
      console.error(error)
      return ''
    }
  }

  async saveConfig(config: any) {
    await this.storage.saveConfigData(config)
  }

  async readConfig() {
    const config = await this.storage.readConfigData()
    return config
  }
}
